###################################################
### chunk number 1: 
###################################################
library(tgp)
options(width=65)


###################################################
### chunk number 2: 
###################################################
bgp


###################################################
### chunk number 3: gpllm
###################################################
hist(c(rgamma(100000,1,20), rgamma(100000,10,10)), 
     breaks=50, xlim=c(0,2), freq=FALSE, ylim=c(0,3),
     main = "p(d) = G(1,20) + G(10,10)", xlab="d")
d <- seq(0,2,length=1000)
lines(d,0.2+0.7/(1+exp(-10*(d-0.5))))
abline(h=1, lty=2)
legend(x=1.25, y=2.5, c("p(b) = 1", "p(b|d)"), lty=c(1,2))


###################################################
### chunk number 4: 
###################################################
graphics.off()


###################################################
### chunk number 5: 
###################################################
library(tgp)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 6: 
###################################################
# 1-d linear data input and predictive data
X <- seq(0,1,length=50)  # inputs
XX <- seq(0,1,length=99) # predictive locations
Z <- 1 + 2*X + rnorm(length(X),sd=0.25) # responses


###################################################
### chunk number 7: 
###################################################
lin.blm <- blm(X=X, XX=XX, Z=Z)


###################################################
### chunk number 8: linear-blm
###################################################
plot(lin.blm, main='Linear Model,', layout='surf')
abline(1,2,lty=3,col='blue')


###################################################
### chunk number 9: 
###################################################
graphics.off()


###################################################
### chunk number 10: 
###################################################
lin.gpllm <- bgpllm(X=X, XX=XX, Z=Z)


###################################################
### chunk number 11: linear-gplm
###################################################
plot(lin.gpllm, main='GP LLM,', layout='surf')
abline(1,2,lty=4,col='blue')


###################################################
### chunk number 12: 
###################################################
graphics.off()


###################################################
### chunk number 13: 
###################################################
lin.gpllm.tr <- bgpllm(X=X, XX=0.5, Z=Z, pred.n=FALSE, trace=TRUE,
                       verb=0)
mla <- mean(lin.gpllm.tr$trace$linarea$la)
mla


###################################################
### chunk number 14: 
###################################################
1-mean(lin.gpllm.tr$trace$XX[[1]]$b1)


###################################################
### chunk number 15: 
###################################################
library(tgp)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 16: 
###################################################
X <- seq(0,20,length=100)
XX <- seq(0,20,length=99)
Ztrue <- (sin(pi*X/5) + 0.2*cos(4*pi*X/5)) * (X <= 9.6)
lin <- X>9.6; 
Ztrue[lin] <- -1 + X[lin]/10
Z <- Ztrue + rnorm(length(Ztrue), sd=0.1)


###################################################
### chunk number 17: 
###################################################
sin.bgp <- bgp(X=X, Z=Z, XX=XX, verb=0)


###################################################
### chunk number 18: sin-bgp
###################################################
plot(sin.bgp, main='GP,', layout='surf')
lines(X, Ztrue, col=4, lty=2, lwd=2)


###################################################
### chunk number 19: 
###################################################
graphics.off()


###################################################
### chunk number 20: 
###################################################
sin.btlm <- btlm(X=X, Z=Z, XX=XX)


###################################################
### chunk number 21: sin-btlm
###################################################
plot(sin.btlm, main='treed LM,', layout='surf')
lines(X, Ztrue, col=4, lty=2, lwd=2)


###################################################
### chunk number 22: 
###################################################
graphics.off()


###################################################
### chunk number 23: sin-btlmtrees
###################################################
tgp.trees(sin.btlm)


###################################################
### chunk number 24: 
###################################################
graphics.off()


###################################################
### chunk number 25: 
###################################################
sin.btgp <- btgp(X=X, Z=Z, XX=XX, verb=0)


###################################################
### chunk number 26: sin-btgp
###################################################
plot(sin.btgp, main='treed GP,', layout='surf')
lines(X, Ztrue, col=4, lty=2, lwd=2)


###################################################
### chunk number 27: 
###################################################
graphics.off()


###################################################
### chunk number 28: 
###################################################
library(tgp)
library(maptree)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 29: 
###################################################
exp2d.data <- exp2d.rand()
X <- exp2d.data$X; Z <- exp2d.data$Z
XX <- exp2d.data$XX


###################################################
### chunk number 30: 
###################################################
exp.bgp <- bgp(X=X, Z=Z, XX=XX, corr="exp", verb=0) 	


###################################################
### chunk number 31: exp-bgp
###################################################
plot(exp.bgp, main='GP,')


###################################################
### chunk number 32: 
###################################################
graphics.off()


###################################################
### chunk number 33: 
###################################################
exp.btgp <- btgp(X=X, Z=Z, XX=XX, corr="exp", verb=0)


###################################################
### chunk number 34: exp-btgp
###################################################
plot(exp.btgp, main='treed GP,')


###################################################
### chunk number 35: 
###################################################
graphics.off()


###################################################
### chunk number 36: exp-btgptrees
###################################################
tgp.trees(exp.btgp)


###################################################
### chunk number 37: 
###################################################
graphics.off()


###################################################
### chunk number 38: 
###################################################
exp.btgpllm <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", R=2) 	


###################################################
### chunk number 39: exp-btgpllm
###################################################
plot(exp.btgpllm, main='treed GP LLM,')


###################################################
### chunk number 40: 
###################################################
graphics.off()


###################################################
### chunk number 41: exp-1dbtgpllm1
###################################################
plot(exp.btgpllm, main='treed GP LLM,', proj=c(1))


###################################################
### chunk number 42: 
###################################################
graphics.off()


###################################################
### chunk number 43: exp-1dbtgpllm2
###################################################
plot(exp.btgpllm, main='treed GP LLM,', proj=c(2))


###################################################
### chunk number 44: 
###################################################
graphics.off()


###################################################
### chunk number 45: 
###################################################
library(tgp)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 46: 
###################################################
library(MASS)
X <- data.frame(times=mcycle[,1])
Z <- data.frame(accel=mcycle[,2])


###################################################
### chunk number 47: 
###################################################
moto.bgp <- bgp(X=X, Z=Z, verb=0)


###################################################
### chunk number 48: moto-bgp
###################################################
plot(moto.bgp, main='GP,', layout='surf')


###################################################
### chunk number 49: 
###################################################
graphics.off()


###################################################
### chunk number 50: 
###################################################
moto.btlm <- btlm(X=X, Z=Z, verb=0)


###################################################
### chunk number 51: moto-btlm
###################################################
plot(moto.btlm, main='Bayesian CART,', layout='surf')


###################################################
### chunk number 52: 
###################################################
graphics.off()


###################################################
### chunk number 53: 
###################################################
moto.btgpllm <- btgpllm(X=X, Z=Z, bprior="b0", verb=0)
moto.btgpllm.p <- predict(moto.btgpllm) ## using MAP


###################################################
### chunk number 54: moto-btgp
###################################################
par(mfrow=c(1,2))
plot(moto.btgpllm, main='treed GP LLM,', layout='surf')
plot(moto.btgpllm.p, center='km', layout='surf')


###################################################
### chunk number 55: 
###################################################
graphics.off()


###################################################
### chunk number 56: moto-btgpq
###################################################
par(mfrow=c(1,2))
plot(moto.btgpllm, main='treed GP LLM,', layout='as')
plot(moto.btgpllm.p, as='ks2', layout='as')


###################################################
### chunk number 57: 
###################################################
graphics.off()


###################################################
### chunk number 58: 
###################################################
library(tgp)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 59: 
###################################################
f <- friedman.1.data(200)
ff <- friedman.1.data(1000)
X <- f[,1:10]; Z <- f$Y
XX <- ff[,1:10]


###################################################
### chunk number 60: 
###################################################
fr.btlm <- btlm(X=X, Z=Z, XX=XX, tree=c(0.95,2), pred.n=FALSE, verb=0)
fr.btlm.mse <- sqrt(mean((fr.btlm$ZZ.mean - ff$Ytrue)^2))
fr.btlm.mse


###################################################
### chunk number 61: 
###################################################
fr.bgpllm <- bgpllm(X=X, Z=Z, XX=XX, pred.n=FALSE, verb=0)
fr.bgpllm.mse <- sqrt(mean((fr.bgpllm$ZZ.mean - ff$Ytrue)^2))
fr.bgpllm.mse


###################################################
### chunk number 62: 
###################################################
XX1 <- matrix(rep(0,10), nrow=1)
fr.bgpllm.tr <- bgpllm(X=X, Z=Z, XX=XX1, pred.n=FALSE, trace=TRUE, 
                       m0r1=FALSE, verb=0)


###################################################
### chunk number 63: 
###################################################
trace <- fr.bgpllm.tr$trace$XX[[1]]
apply(trace[,27:36], 2, mean)


###################################################
### chunk number 64: 
###################################################
mean(fr.bgpllm.tr$trace$linarea$ba)


###################################################
### chunk number 65: 
###################################################
summary(trace[,9:10])


###################################################
### chunk number 66: 
###################################################
apply(trace[,11:15], 2, mean)


###################################################
### chunk number 67: 
###################################################
library(tgp)
library(maptree)
#options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 68: 
###################################################
exp2d.data <- exp2d.rand(lh=0, dopt=10)
X <- exp2d.data$X
Z <- exp2d.data$Z
Xcand <- lhs(1000, rbind(c(-2,6),c(-2,6)))


###################################################
### chunk number 69: 
###################################################
exp1 <- btgpllm(X=X, Z=Z, pred.n=FALSE, corr="exp", R=5, verb=0)


###################################################
### chunk number 70: as-mapt
###################################################
tgp.trees(exp1)


###################################################
### chunk number 71: 
###################################################
graphics.off()


###################################################
### chunk number 72: 
###################################################
XX <- tgp.design(200, Xcand, exp1)
XX <- rbind(XX, c(-sqrt(1/2),0))


###################################################
### chunk number 73: as-cands
###################################################
plot(exp1$X, pch=19, cex=0.5)
points(XX)
mapT(exp1, add=TRUE)


###################################################
### chunk number 74: 
###################################################
graphics.off()


###################################################
### chunk number 75: 
###################################################
exp.as <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", improv=TRUE, 
                        Ds2x=TRUE, R=5, verb=0)


###################################################
### chunk number 76: as-expas
###################################################
par(mfrow=c(1,3), bty="n")
plot(exp.as, main="tgpllm,", layout="as", as="alm")
plot(exp.as, main="tgpllm,", layout='as', as='alc')
plot(exp.as, main="tgpllm,", layout='as', as='improv')


###################################################
### chunk number 77: 
###################################################
graphics.off()


###################################################
### chunk number 78: 
###################################################
library(tgp)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 79: 
###################################################
exp2d.data <- exp2d.rand(n2=150, lh=0, dopt=10)
X <- exp2d.data$X
Z <- exp2d.data$Z
XX <- rbind(c(0,0),c(2,2),c(4,4))


###################################################
### chunk number 80: 
###################################################
out <- btgpllm(X=X, Z=Z, XX=XX, corr="exp", bprior="b0", 
               pred.n=FALSE, Ds2x=TRUE, R=10, #BTE=c(2000,5000,10),
               trace=TRUE, verb=0)


###################################################
### chunk number 81: 
###################################################
out$trace


###################################################
### chunk number 82: traces-XXd
###################################################
trXX <- out$trace$XX; ltrXX <- length(trXX)
y <- trXX[[1]]$d
for(i in 2:ltrXX) y <- c(y, trXX[[i]]$d)
plot(log(trXX[[1]]$d), type="l", ylim=range(log(y)), ylab="log(d)",
     main="range (d) parameter traces")
names <- "XX[1,]"
for(i in 2:ltrXX) {
  lines(log(trXX[[i]]$d), col=i, lty=i)
  names <- c(names, paste("XX[", i, ",]", sep=""))
}
legend("bottomleft", names, col=1:ltrXX, lty=1:ltrXX)


###################################################
### chunk number 83: 
###################################################
graphics.off()


###################################################
### chunk number 84: 
###################################################
linarea <- mean(out$trace$linarea$la)
linarea


###################################################
### chunk number 85: traces-la
###################################################
hist(out$trace$linarea$la)


###################################################
### chunk number 86: 
###################################################
graphics.off()


###################################################
### chunk number 87: 
###################################################
m <- matrix(0, nrow=length(trXX), ncol=3)#ncol=5)
for(i in 1:length(trXX))
  m[i,] <- as.double(c(out$XX[i,], mean(trXX[[i]]$b)))
m <- data.frame(cbind(m, 1-m[,3]))
names(m)=c("XX1","XX2","b","pllm")
m


###################################################
### chunk number 88: traces-alc
###################################################
trALC <- out$trace$preds$Ds2x
y <- trALC[,1]
for(i in 2:ncol(trALC)) y <- c(y, trALC[,i])
plot(log(trALC[,1]), type="l", ylim=range(log(y)), ylab="Ds2x",
     main="ALC: samples from Ds2x")
names <- "XX[1,]"
for(i in 2:ncol(trALC)) {
  lines(log(trALC[,i]), col=i, lty=i)
  names <- c(names, paste("XX[", i, ",]", sep=""))
}
legend("bottomright", names, col=1:ltrXX, lty=1:ltrXX)


###################################################
### chunk number 89: 
###################################################
graphics.off()


###################################################
### chunk number 90: 
###################################################
library(tgp)
library(maptree)
##options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 91: 
###################################################
library(MASS)
out <- btgpllm(X=mcycle[,1], Z=mcycle[,2], bprior="b0", 
	       pred.n=FALSE, verb=0) 
save(out, file="out.Rsave")
out <- NULL


###################################################
### chunk number 92: 
###################################################
load("out.Rsave")
XX <- seq(2.4, 56.7, length=200)
out.kp <- predict(out, XX=XX, pred.n=FALSE)


###################################################
### chunk number 93: 
###################################################
out.p <- predict(out, XX=XX, pred.n=FALSE, BTE=c(0,1000,1))


###################################################
### chunk number 94: 
###################################################
out2 <- predict(out, XX, pred.n=FALSE, BTE=c(0,2000,2), MAP=FALSE)


###################################################
### chunk number 95: pred-kp
###################################################
plot(out.kp, center="km", as="ks2")


###################################################
### chunk number 96: 
###################################################
graphics.off()


###################################################
### chunk number 97: pred-p
###################################################
plot(out.p)


###################################################
### chunk number 98: 
###################################################
graphics.off()


###################################################
### chunk number 99: pred-2
###################################################
plot(out2)


###################################################
### chunk number 100: 
###################################################
graphics.off()


###################################################
### chunk number 101: 
###################################################
unlink("out.Rsave")


